repling.clj-agent.agent


connect-provider!clj

(connect-provider! agent provider-ref)
(connect-provider! agent provider-name provider-ref)

Connects the agent to a provider.

Connects the agent to a provider.
raw docstring

default-interactions-rootclj

(default-interactions-root)

Returns the default root directory for stored interactions.

Returns the default root directory for stored interactions.
raw docstring

disconnect-provider!clj

(disconnect-provider! agent)

Disconnects the current provider.

Disconnects the current provider.
raw docstring

interactions-directoryclj

(interactions-directory agent)

Returns the directory where this agent stores prompt interactions.

Returns the directory where this agent stores prompt interactions.
raw docstring

list-interactionsclj

(list-interactions agent)

Lists persisted interaction files for an agent.

Lists persisted interaction files for an agent.
raw docstring

project-folder-identifierclj

(project-folder-identifier)
(project-folder-identifier project-dir)

Builds a stable identifier for a project directory.

Builds a stable identifier for a project directory.
raw docstring

prompt!clj

(prompt! agent request)

Sends a prompt or request map to the connected provider.

Sends a prompt or request map to the connected provider.
raw docstring

providerclj

(provider agent)

Returns the connected provider summary, if any.

Returns the connected provider summary, if any.
raw docstring

read-interactionclj

(read-interaction path)

Reads a persisted interaction file as a vector of messages.

Reads a persisted interaction file as a vector of messages.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries