(connect-provider! agent provider-ref)(connect-provider! agent provider-name provider-ref)Connects the agent to a provider.
Connects the agent to a provider.
(default-interactions-root)Returns the default root directory for stored interactions.
Returns the default root directory for stored interactions.
(disconnect-provider! agent)Disconnects the current provider.
Disconnects the current provider.
(interactions-directory agent)Returns the directory where this agent stores prompt interactions.
Returns the directory where this agent stores prompt interactions.
(list-interactions agent)Lists persisted interaction files for an agent.
Lists persisted interaction files for an agent.
(project-folder-identifier)(project-folder-identifier project-dir)Builds a stable identifier for a project directory.
Builds a stable identifier for a project directory.
(prompt! agent request)Sends a prompt or request map to the connected provider.
Sends a prompt or request map to the connected provider.
(provider agent)Returns the connected provider summary, if any.
Returns the connected provider summary, if any.
(read-interaction path)Reads a persisted interaction file as a vector of messages.
Reads a persisted interaction file as a vector of messages.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |