(eval-string agent code)Evaluates code in an SCI runtime where registered tools are directly callable.
Evaluates code in an SCI runtime where registered tools are directly callable.
(list-tools agent)Returns the registered tool metadata.
Returns the registered tool metadata.
(lookup-tool agent tool-ref)Finds a tool by handle or by name.
Finds a tool by handle or by name.
(make-agent)(make-agent initial-tools)(make-agent initial-tools
{:keys [project-dir interactions-root]
:or {project-dir "."
interactions-root (agent-runtime/default-interactions-root)}})Creates a tiny agent that stores callable tools and exposes them through SCI.
Creates a tiny agent that stores callable tools and exposes them through SCI.
(register-tool! agent tool-ref)(register-tool! agent tool-name-or-class tool-ref-or-method-name)(register-tool! agent tool-name class-ref method-name)Registers a tool backed by a var, function, or Java method.
Registers a tool backed by a var, function, or Java method.
(unregister-tool! agent tool-ref)(unregister-tool! agent class-ref method-name)Removes a registered tool.
Removes a registered tool.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |