repling.clj-agent.tool


*rg-command*clj

Shell command used for ripgrep lookups.

Shell command used for ripgrep lookups.
raw docstring

edit-fileclj

(edit-file path find replace)
(edit-file path
           find
           replace
           {:keys [replace-all? charset] :or {charset "UTF-8"}})

Edits a file via simple string replacement.

Edits a file via simple string replacement.
raw docstring

globclj

(glob path pattern)

Lists files under a path that match a glob pattern.

Lists files under a path that match a glob pattern.
raw docstring

grepclj

(grep path pattern)
(grep path pattern glob-pattern)
(grep path pattern glob-pattern ignore-case?)

Searches file contents with ripgrep when available, otherwise with Java.

Searches file contents with ripgrep when available, otherwise with Java.
raw docstring

read-fileclj

(read-file path)
(read-file path charset)

Reads a text file.

Reads a text file.
raw docstring

write-fileclj

(write-file path content)
(write-file path content {:keys [append? charset] :or {charset "UTF-8"}})

Writes a text file, creating parent directories when needed.

Writes a text file, creating parent directories when needed.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries